@@ -14,7 +14,7 @@ Usage::
 """
 from typing import Any, Dict, Type
 
-from botocore.client import ClientMeta
+from botocore.client import BaseClient, ClientMeta
 
 from .type_defs import GetRawMessageContentResponseTypeDef, RawMessageContentTypeDef
 
@@ -37,20 +37,25 @@ class Exceptions:
     ResourceNotFoundException: Type[BotocoreClientError]
 
 
-class WorkMailMessageFlowClient:
+class WorkMailMessageFlowClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workmailmessageflow/client.html)
     """
 
     meta: ClientMeta
-    exceptions: Exceptions
+
+    @property
+    def exceptions(self) -> Exceptions:
+        """
+        WorkMailMessageFlowClient exceptions.
+        """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workmailmessageflow/client.html#can_paginate)
         """
 
@@ -64,7 +69,7 @@ class WorkMailMessageFlowClient:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workmailmessageflow/client.html#generate_presigned_url)
         """
 
@@ -72,7 +77,7 @@ class WorkMailMessageFlowClient:
         """
         Retrieves the raw content of an in-transit email message, in MIME format.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client.get_raw_message_content)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client.get_raw_message_content)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workmailmessageflow/client.html#get_raw_message_content)
         """
 
@@ -82,6 +87,6 @@ class WorkMailMessageFlowClient:
         """
         Updates the raw content of an in-transit email message, in MIME format.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client.put_raw_message_content)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client.put_raw_message_content)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workmailmessageflow/client.html#put_raw_message_content)
         """
